@@ -1,17 +1,21 @@
-use ansi_term::Colour::Red;
 use clap::{crate_version, Parser};
 use itertools::Itertools;
+use nu_ansi_term::Color::Red;
 
 use debcargo::cli::{Cli, Opt};
 use debcargo::crates::CrateInfo;
 use debcargo::debian::DebInfo;
 use debcargo::errors::Result;
-use debcargo::package::*;
+use debcargo::package::PackageProcess;
 use debcargo::{
     build_order::build_order, crates::invalidate_crates_io_cache,
     deb_dependencies::deb_dependencies,
 };
 
+#[cfg(feature = "update-dependencies")]
+use debcargo::update_dependencies::update_dependencies;
+use Opt::{BuildOrder, DebDependencies, DebSrcName, Extract, Package, Update};
+
 #[test]
 fn verify_app() {
     use clap::CommandFactory;
@@ -20,7 +24,6 @@ fn verify_app() {
 
 fn real_main() -> Result<()> {
     let m = Cli::parse();
-    use Opt::*;
     match m.command {
         Update => invalidate_crates_io_cache(),
         DebSrcName {
@@ -28,7 +31,7 @@ fn real_main() -> Result<()> {
             version,
         } => {
             let crate_info = CrateInfo::new_with_update(&crate_name, version.as_deref(), false)?;
-            let deb_info = DebInfo::new(&crate_info, crate_version!(), version.is_some());
+            let deb_info = DebInfo::new(&crate_info, crate_version!(), version.is_some(), None);
             println!("{}", deb_info.package_name());
             Ok(())
         }
@@ -53,31 +56,33 @@ fn real_main() -> Result<()> {
             log::info!("preparing orig tarball");
             process.prepare_orig_tarball()?;
             log::info!("preparing debian folder");
-            process.prepare_debian_folder(finish)?;
+            process.prepare_debian_folder(&finish)?;
             process.post_package_checks()
         }
         BuildOrder { args } => {
-            let build_order = build_order(args)?;
+            let build_order = build_order(&args)?;
             for v in &build_order {
-                println!("{}", v);
+                println!("{v}");
             }
             Ok(())
         }
         DebDependencies { args } => {
-            let (toolchain_deps, dependencies) = deb_dependencies(args)?;
+            let (toolchain_deps, dependencies) = deb_dependencies(&args)?;
             println!(
                 "{}",
                 toolchain_deps.into_iter().chain(dependencies).join(", ")
             );
             Ok(())
         }
+        #[cfg(feature = "update-dependencies")]
+        UpdateDependencies { args } => update_dependencies(args),
     }
 }
 
 fn main() {
     env_logger::init();
     if let Err(e) = real_main() {
-        eprintln!("{}", Red.bold().paint(format!("debcargo failed: {:?}", e)));
+        eprintln!("{}", Red.bold().paint(format!("debcargo failed: {e:?}")));
         std::process::exit(1);
     }
 }
