@@ -4,6 +4,7 @@ use std::path::{Path, PathBuf};
 
 use anyhow::Context;
 use cargo::core::{Dependency, PackageId};
+use cargo::util::interning::InternedString;
 use clap::{Parser, ValueEnum};
 
 use crate::config::Config;
@@ -15,6 +16,7 @@ use crate::debian::control::base_deb_name;
 use crate::errors::Result;
 use crate::package::{PackageExtractArgs, PackageProcess};
 use crate::util;
+use ResolveType::{BinaryAllForDebianTesting, SourceForDebianUnstable};
 
 #[derive(Debug, Clone, Copy, ValueEnum)]
 #[value(rename_all = "verbatim")]
@@ -80,12 +82,11 @@ fn get_build_deps(
         .union(&additional_deps)
         .cloned()
         .collect::<Vec<_>>();
-    use ResolveType::*;
     match resolve_type {
         SourceForDebianUnstable => Ok((hard_deps, vec![])),
         BinaryAllForDebianTesting => {
             let mut soft_deps = all_deps;
-            for h in hard_deps.iter() {
+            for h in &hard_deps {
                 soft_deps.remove(h);
             }
             Ok((hard_deps, soft_deps.into_iter().collect::<Vec<_>>()))
@@ -97,10 +98,10 @@ fn dep_features(dep: &Dependency) -> Vec<&'static str> {
     let mut feats = dep
         .features()
         .iter()
-        .map(|x| x.as_str())
+        .map(InternedString::as_str)
         .collect::<Vec<_>>();
     if dep.uses_default_features() {
-        feats.push("default")
+        feats.push("default");
     }
     feats.push(""); // bare-bones library with no features
     feats
@@ -122,7 +123,7 @@ fn find_config(config_dir: &Path, id: PackageId) -> Result<(Option<PathBuf>, Con
         let path = config_dir.join(c).join("debian").join("debcargo.toml");
         if path.is_file() {
             let config = Config::parse(&path).context("failed to parse debcargo.toml")?;
-            log::debug!("using config for {}: {:?}", id, path);
+            log::debug!("using config for {id}: {path:?}");
             return Ok((Some(path), config));
         }
     }
@@ -149,37 +150,36 @@ fn resolve_info(
     if let std::collections::btree_map::Entry::Vacant(e) = infos.entry(id) {
         let id = *e.key();
         let default_config = Config::default();
-        let (config_path, config) = match config_dir {
-            None => (None, default_config),
-            Some(config_dir) => {
-                let (config_path, config) = find_config(config_dir, id)?;
-                match config_path {
-                    None => (None, default_config),
-                    Some(_) => (config_path, config),
-                }
+        let (config_path, config) = if let Some(config_dir) = config_dir {
+            let (config_path, config) = find_config(config_dir, id)?;
+            if config_path.is_none() {
+                (None, default_config)
+            } else {
+                (config_path, config)
             }
+        } else {
+            (None, default_config)
         };
-        let (info, config) = match config_path {
-            None => (info, config),
-            Some(_) => {
-                let mut process = PackageProcess::new(info, config_path, config)?;
-                let tempdir = tempfile::Builder::new()
-                    .prefix("debcargo")
-                    .tempdir_in(".")?;
-                process.extract(PackageExtractArgs {
-                    directory: Some(tempdir.path().to_path_buf()),
-                })?;
-                process.apply_overrides()?;
-                (process.crate_info, process.config)
-            }
+        let (info, config) = if config_path.is_none() {
+            (info, config)
+        } else {
+            let mut process = PackageProcess::new(info, config_path, config)?;
+            let tempdir = tempfile::Builder::new()
+                .prefix("debcargo")
+                .tempdir_in(".")?;
+            process.extract(PackageExtractArgs {
+                directory: Some(tempdir.path().to_path_buf()),
+            })?;
+            process.apply_overrides()?;
+            (process.crate_info, process.config)
         };
         let dep_info = all_dependencies_and_features(info.manifest());
         e.insert((info, dep_info, config));
-    };
+    }
     Ok(id)
 }
 
-pub fn build_order(args: BuildOrderArgs) -> Result<Vec<PackageId>> {
+pub fn build_order(args: &BuildOrderArgs) -> Result<Vec<PackageId>> {
     let crate_name = &args.crate_name;
     let version = args.version.as_deref();
     let config_dir = args.config_dir.as_deref();
@@ -190,7 +190,7 @@ pub fn build_order(args: BuildOrderArgs) -> Result<Vec<PackageId>> {
     let seed_id = resolve_info(&mut infos, &mut cache, config_dir, &seed_dep, true)?;
 
     let mut next = |idf: &PackageIdFeat| -> Result<(Vec<PackageIdFeat>, Vec<PackageIdFeat>)> {
-        log::trace!("{} getting build deps..", idf);
+        log::trace!("{idf} getting build deps..");
         let (hard, soft) = get_build_deps(
             infos
                 .get(&idf.0)
@@ -241,7 +241,7 @@ pub fn build_order(args: BuildOrderArgs) -> Result<Vec<PackageId>> {
 
     let succ_with_features =
         util::graph_from_succ([PackageIdFeat(seed_id, "")], &mut next, &mut log)?;
-    log::trace!("succ_with_features: {:#?}", succ_with_features);
+    log::trace!("succ_with_features: {succ_with_features:#?}");
 
     let succ = util::succ_proj(&succ_with_features, |x| x.0);
     let pred = util::succ_to_pred(&succ);
@@ -250,7 +250,7 @@ pub fn build_order(args: BuildOrderArgs) -> Result<Vec<PackageId>> {
         .filter_map(|(k, v)| if v.is_empty() { Some(*k) } else { None })
         .collect::<BTreeSet<_>>();
     // swap pred/succ for call to topo_sort since we want reverse topo order
-    let build_order = match util::topo_sort(roots, pred.clone(), succ.clone()) {
+    let build_order = match util::topo_sort(roots, &pred, succ.clone()) {
         Ok(r) => r,
         Err(remain) => {
             log::error!(
@@ -272,9 +272,9 @@ pub fn build_order(args: BuildOrderArgs) -> Result<Vec<PackageId>> {
     };
 
     // sanity check
-    for p in build_order.iter() {
+    for p in &build_order {
         if infos.remove(p).is_none() {
-            log::error!("extra package in build-order not in infos: {}", p);
+            log::error!("extra package in build-order not in infos: {p}");
         }
     }
     for (p, _) in infos {
