@@ -5,8 +5,10 @@ use std::cmp;
 use std::fmt;
 
 use crate::config::testing_ignore_debpolv;
+use crate::debian::dependency::V::{M, MM, MMP};
 use crate::debian::{self, control::base_deb_name, Package};
-use crate::errors::*;
+use crate::errors::Result;
+use semver::Op::{Caret, Exact, Greater, GreaterEq, Less, LessEq, Tilde, Wildcard};
 
 #[derive(Eq, Clone)]
 #[allow(clippy::upper_case_acronyms)]
@@ -18,7 +20,7 @@ enum V {
 
 impl V {
     fn new(p: &semver::Comparator) -> Result<Self> {
-        use self::V::*;
+        use self::V::{M, MM, MMP};
         let mmp = match (p.minor, p.patch) {
             (None, None) => M(p.major),
             (Some(minor), None) => MM(p.major, minor),
@@ -29,7 +31,7 @@ impl V {
     }
 
     fn inclast(&self) -> V {
-        use self::V::*;
+        use self::V::{M, MM, MMP};
         match *self {
             M(major) => M(major + 1),
             MM(major, minor) => MM(major, minor + 1),
@@ -38,7 +40,7 @@ impl V {
     }
 
     fn mmp(&self) -> (u64, u64, u64) {
-        use self::V::*;
+        use self::V::{M, MM, MMP};
         match *self {
             M(major) => (major, 0, 0),
             MM(major, minor) => (major, minor, 0),
@@ -67,11 +69,11 @@ impl PartialEq for V {
 
 impl fmt::Display for V {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        use self::V::*;
+        use self::V::{M, MM, MMP};
         match *self {
-            M(major) => write!(f, "{}", major),
-            MM(major, minor) => write!(f, "{}.{}", major, minor),
-            MMP(major, minor, patch) => write!(f, "{}.{}.{}", major, minor, patch),
+            M(major) => write!(f, "{major}"),
+            MM(major, minor) => write!(f, "{major}.{minor}"),
+            MMP(major, minor, patch) => write!(f, "{major}.{minor}.{patch}"),
         }
     }
 }
@@ -90,7 +92,7 @@ impl VRange {
         match self.ge {
             Some(ref ge_) if &ge < ge_ => (),
             _ => self.ge = Some(ge),
-        };
+        }
         self
     }
 
@@ -98,16 +100,16 @@ impl VRange {
         match self.lt {
             Some(ref lt_) if &lt >= lt_ => (),
             _ => self.lt = Some(lt),
-        };
+        }
         self
     }
 
     fn to_deb_clause(&self, base: &str, suffix: &str) -> Result<Vec<String>> {
-        use debian::dependency::V::*;
+        use debian::dependency::V::{M, MM};
         match (&self.ge, &self.lt) {
             (None, None) => Ok(vec![format!("{}{}", base, suffix)]),
-            (Some(ge), None) => Ok(vec![format!("{}{} (>= {}-~~)", base, suffix, ge)]),
-            (None, Some(lt)) => Ok(vec![format!("{}{} (<< {}-~~)", base, suffix, lt)]),
+            (Some(ge), None) => Ok(vec![format!("{}{} (>= {})", base, suffix, ge)]),
+            (None, Some(lt)) => Ok(vec![format!("{}{} (<< {})", base, suffix, lt)]),
             (Some(ge), Some(lt)) => {
                 if ge >= lt {
                     debcargo_bail!("bad version range: >= {}, << {}", ge, lt);
@@ -146,21 +148,21 @@ impl VRange {
                         ranges.push((Some(MM(ge_maj, ge_min)), true, ge));
                         ranges.push((Some(MM(lt_maj, lt_min)), false, lt));
                     }
-                };
+                }
                 // unversioned package name is only provided by the non semver-suffixed packages
                 // if a range is only satisfiable by semver-suffixed variants in the archive, it
                 // needs to be collapsed/reduced accordingly
                 Ok(ranges
                     .iter()
                     .filter_map(|(ver, greater, cons)| match (ver, greater, cons) {
-                        (None, true, c) => Some(format!("{}{} (>= {}-~~)", base, suffix, c)),
-                        (None, false, c) => Some(format!("{}{} (<< {}-~~)", base, suffix, c)),
+                        (None, true, c) => Some(format!("{base}{suffix} (>= {c})")),
+                        (None, false, c) => Some(format!("{base}{suffix} (<< {c})")),
                         (Some(ver), true, c) => {
                             if c == &ver {
                                 // A-x >= x is redundant, drop the >=
-                                Some(format!("{}-{}{}", base, ver, suffix))
+                                Some(format!("{base}-{ver}{suffix}"))
                             } else {
-                                Some(format!("{}-{}{} (>= {}-~~)", base, ver, suffix, c))
+                                Some(format!("{base}-{ver}{suffix} (>= {c})"))
                             }
                         }
                         (Some(ver), false, c) => {
@@ -168,7 +170,7 @@ impl VRange {
                                 // A-x << x is unsatisfiable, drop it
                                 None
                             } else {
-                                Some(format!("{}-{}{} (<< {}-~~)", base, ver, suffix, c))
+                                Some(format!("{base}-{ver}{suffix} (<< {c})"))
                             }
                         }
                     })
@@ -195,7 +197,7 @@ fn coerce_unacceptable_predicate<'a>(
                 "Coercing removal of prerelease part of dependency: {} {:?}",
                 dep.package_name(),
                 p
-            )
+            );
         } else {
             debcargo_bail!(
                 "Cannot represent prerelease part of dependency: {} {:?}",
@@ -205,8 +207,6 @@ fn coerce_unacceptable_predicate<'a>(
         }
     }
 
-    use debian::dependency::V::M;
-    use semver::Op::*;
     match (&p.op, mmp) {
         (&Greater, &M(0)) => Ok(&p.op),
         (&GreaterEq, &M(0)) => {
@@ -235,12 +235,10 @@ fn generate_version_constraints(
     op: &semver::Op,
 ) -> Result<()> {
     let mmp = V::new(p)?;
-    use debian::dependency::V::*;
-    use semver::Op::*;
     // see https://doc.rust-lang.org/cargo/reference/specifying-dependencies.html
     // and https://docs.rs/semver/1/semver/enum.Op.html for semantics
     match (*op, &mmp) {
-        (Less, &M(0)) | (Less, &MM(0, 0)) | (Less, &MMP(0, 0, 0)) => debcargo_bail!(
+        (Less, &M(0) | &MM(0, 0) | &MMP(0, 0, 0)) => debcargo_bail!(
             "Unrepresentable dependency version predicate: {} {:?}",
             dep.package_name(),
             p
@@ -257,11 +255,11 @@ fn generate_version_constraints(
         (GreaterEq, _) => {
             vr.constrain_ge(mmp);
         }
-        (Exact, _) | (Wildcard, _) => {
+        (Exact | Wildcard, _) => {
             vr.constrain_lt(mmp.inclast());
             vr.constrain_ge(mmp);
         }
-        (Tilde, &M(_)) | (Tilde, &MM(_, _)) => {
+        (Tilde, &M(_) | &MM(_, _)) => {
             vr.constrain_lt(mmp.inclast());
             vr.constrain_ge(mmp);
         }
@@ -274,11 +272,11 @@ fn generate_version_constraints(
             vr.constrain_lt(mmp.inclast());
             vr.constrain_ge(mmp);
         }
-        (Caret, &MMP(0, minor, _)) | (Caret, &MM(0, minor)) => {
+        (Caret, &MMP(0, minor, _) | &MM(0, minor)) => {
             vr.constrain_lt(MM(0, minor + 1));
             vr.constrain_ge(mmp);
         }
-        (Caret, &MMP(major, _, _)) | (Caret, &MM(major, _)) | (Caret, &M(major)) => {
+        (Caret, &MMP(major, _, _) | &MM(major, _) | &M(major)) => {
             vr.constrain_lt(M(major + 1));
             vr.constrain_ge(mmp);
         }
