@@ -1,7 +1,6 @@
 use std::collections::{BTreeMap, BTreeSet, HashMap, HashSet};
 use std::fs;
 use std::io::{self, ErrorKind, Read, Seek, Write as IoWrite};
-use std::ops::Deref;
 #[cfg(unix)]
 use std::os::unix::fs::PermissionsExt;
 use std::path::{Path, PathBuf};
@@ -23,7 +22,7 @@ use crate::config::{package_field_for_feature, testing_ignore_debpolv, Config, P
 use crate::crates::{
     all_dependencies_and_features, show_dep, transitive_deps, CrateDepInfo, CrateInfo,
 };
-use crate::errors::*;
+use crate::errors::Result;
 use crate::util::{self, copy_tree, expect_success, get_transitive_val, traverse_depth};
 
 use self::changelog::{ChangelogEntry, ChangelogIterator};
@@ -42,7 +41,7 @@ pub struct DebInfo {
     /// Debian package name without `rust-` prefix or any semver suffix
     base_package_name: String,
     /// Package name suffix after the base package name.
-    /// Some implies semver_suffix, i.e. Some("") is different from None
+    /// Some implies `semver_suffix`, i.e. Some("") is different from None
     name_suffix: Option<String>,
     uscan_version_pattern: Option<String>,
     /// Debian package name without `rust-` prefix
@@ -54,7 +53,12 @@ pub struct DebInfo {
 }
 
 impl DebInfo {
-    pub fn new(crate_info: &CrateInfo, debcargo_version: &str, semver_suffix: bool) -> Self {
+    pub fn new(
+        crate_info: &CrateInfo,
+        debcargo_version: &str,
+        semver_suffix: bool,
+        repack_suffix: Option<&str>,
+    ) -> Self {
         let upstream_name = crate_info.package_id().name().to_string();
         let name_dashed = base_deb_name(&upstream_name);
         let base_package_name = name_dashed.to_lowercase();
@@ -69,7 +73,7 @@ impl DebInfo {
         } else {
             (None, None, base_package_name.clone())
         };
-        let deb_upstream_version = deb_upstream_version(crate_info.version());
+        let deb_upstream_version = deb_upstream_version(crate_info.version(), repack_suffix);
         let package_source_dir = PathBuf::from(format!(
             "{}-{}-{}",
             Source::pkg_prefix(),
@@ -132,7 +136,8 @@ impl DebInfo {
 pub fn prepare_orig_tarball(
     crate_info: &CrateInfo,
     tarball: &Path,
-    src_modified: bool,
+    repacked: bool,
+    manifest_normalized: bool,
     output_dir: &Path,
 ) -> Result<()> {
     let crate_file = crate_info.crate_file();
@@ -144,7 +149,7 @@ pub fn prepare_orig_tarball(
     let mut create = fs::OpenOptions::new();
     create.write(true).create_new(true);
 
-    if src_modified {
+    if repacked {
         debcargo_info!("crate tarball was modified; repacking for debian");
         let mut f = crate_file.file();
         f.seek(io::SeekFrom::Start(0))?;
@@ -153,34 +158,49 @@ pub fn prepare_orig_tarball(
             create.open(&temp_archive_path)?,
             Compression::best(),
         ));
+        let mut manifest_handled = false;
 
         for entry in archive.entries()? {
             let entry = entry?;
             let path = entry.path()?.into_owned();
-            if path.ends_with("Cargo.toml") && path.iter().count() == 2 {
+            if manifest_normalized
+                && (path.ends_with("Cargo.toml") || path.ends_with("Cargo.toml.orig"))
+                && path.iter().count() == 2
+            {
                 // Put the rewritten and original Cargo.toml back into the orig tarball
                 let mut new_archive_append = |name: &str| {
                     let mut header = entry.header().clone();
                     let srcpath = output_dir.join(name);
                     header.set_path(path.parent().unwrap().join(name))?;
                     header.set_size(fs::metadata(&srcpath)?.len());
+                    if name == "Cargo.toml" {
+                        // Cargo.toml has epoch 1
+                        header.set_mtime(1);
+                    } else {
+                        // the rest have epoch tar::headers::DETERMINISTIC_TIMESTAMP
+                        // FIXME once exposed publically in the tar crate
+                        header.set_mtime(1153704088);
+                    }
                     header.set_cksum();
                     new_archive.append(&header, fs::File::open(&srcpath)?)
                 };
-                new_archive_append("Cargo.toml")?;
-                new_archive_append("Cargo.toml.orig")?;
+                if !manifest_handled {
+                    new_archive_append("Cargo.toml")?;
+                    new_archive_append("Cargo.toml.orig")?;
+                }
+                manifest_handled = true;
             } else {
                 match crate_info.filter_path(&entry.path()?) {
                     Err(e) => debcargo_bail!(e),
                     Ok(r) => {
-                        if !r {
-                            new_archive.append_data(&mut entry.header().clone(), path, entry)?;
-                        } else {
+                        if r {
                             writeln!(
                                 io::stderr(),
                                 "Filtered out files from .orig.tar.gz: {:?}",
                                 &entry.path()?
                             )?;
+                        } else {
+                            new_archive.append_data(&mut entry.header().clone(), path, entry)?;
                         }
                     }
                 }
@@ -222,7 +242,7 @@ pub fn apply_overlay_and_patches(
         debcargo_warn!(
             "Most of the time you shouldn't overlay debian/control, \
 it's a maintenance burden. Use debcargo.toml instead."
-        )
+        );
     }
     // apply patches to Cargo.toml in case they exist, and re-read it
     if tempdir.path().join("patches").join("series").exists() {
@@ -328,8 +348,7 @@ pub fn prepare_debian_folder(
         let mut cargo_checksum_json = file("cargo-checksum.json")?;
         writeln!(
             cargo_checksum_json,
-            r#"{{"package":"{}","files":{{}}}}"#,
-            checksum
+            r#"{{"package":"{checksum}","files":{{}}}}"#
         )?;
     }
 
@@ -347,6 +366,7 @@ pub fn prepare_debian_folder(
                 Err(_) => (last, last),
             }
         };
+        let excludes = config.excludes.as_deref().unwrap_or_default();
         let dep5_copyright = debian_copyright(
             output_dir,
             crate_info.manifest(),
@@ -355,43 +375,45 @@ pub fn prepare_debian_folder(
             &uploaders,
             year_range,
             copyright_guess_harder,
+            excludes,
         )?;
-        write!(copyright, "{}", dep5_copyright)?;
+        write!(copyright, "{dep5_copyright}")?;
     }
 
     // debian/watch
     {
         let mut watch = file("watch")?;
-        match config.crate_src_path(config_path) {
-            Some(_) => write!(watch, "FIXME add uscan directive for local crate")?,
-            None => {
-                let uscan_version_pattern = deb_info
-                    .uscan_version_pattern
-                    .as_ref()
-                    .map_or_else(|| "@ANY_VERSION@".to_string(), |ref s| s.to_string());
-                writeln!(watch, "Version: 5\n")?;
-                writeln!(
-                    watch,
-                    "Source: https://qa.debian.org/cgi-bin/fakeupstream.cgi?upstream=crates.io/{name}",
-                    name = upstream_name,
-                )?;
-                writeln!(
-                    watch,
-                    "Matching-Pattern:  .*/crates/{name}/{version_pattern}/download",
-                    name = upstream_name,
-                    version_pattern = uscan_version_pattern
-                )?;
-                writeln!(
-                    watch,
-                    r"Filenamemangle: s/.*\/(.*)\/download/{name}-$1\.tar\.gz/g",
-                    name = upstream_name,
-                )?;
-                writeln!(
-                    watch,
-                    r"Uversionmangle: s/(\d)[_\.\-\+]?((RC|rc|pre|dev|beta|alpha)\.?\d*)$/$1~$2/"
-                )?;
+        if config.crate_src_path(config_path).is_some() {
+            write!(watch, "FIXME add uscan directive for local crate")?;
+        } else {
+            let uscan_version_pattern = deb_info
+                .uscan_version_pattern
+                .as_ref()
+                .map_or_else(|| "@ANY_VERSION@".to_string(), ToString::to_string);
+            writeln!(watch, "Version: 5\n")?;
+            writeln!(
+                watch,
+                "Source: https://qa.debian.org/cgi-bin/fakeupstream.cgi?upstream=crates.io/{upstream_name}",
+            )?;
+            writeln!(
+                watch,
+                "Matching-Pattern:  .*/crates/{upstream_name}/{uscan_version_pattern}/download"
+            )?;
+            writeln!(
+                watch,
+                r"Filenamemangle: s/.*\/(.*)\/download/{upstream_name}-$1\.tar\.gz/g",
+            )?;
+            writeln!(
+                watch,
+                r"Uversionmangle: s/(\d)[_\.\-\+]?((RC|rc|pre|dev|beta|alpha)\.?\d*)$/$1~$2/"
+            )?;
+            writeln!(watch, r"Dversionmangle: s/@DEB_EXT@//g",)?;
+            writeln!(watch, r"Compression: gzip")?;
+            if let Some(repack_suffix) = config.repack_suffix() {
+                writeln!(watch, r"Repack: yes")?;
+                writeln!(watch, r"Repacksuffix: +{repack_suffix}")?;
             }
-        };
+        }
     }
 
     // debian/source/format
@@ -499,7 +521,7 @@ echo "debcargo testing: suppressing dh-cargo-built-using";;
         // Special-case d/changelog:
         let (mut changelog, changelog_data) = changelog_or_new(tempdir.path())?;
         let (changelog_old, mut changelog_items, deb_version_suffix) = {
-            let ver_bump = &|e: &Option<&str>| -> Result<Option<String>> {
+            let ver_bump = &|e: Option<&str>| -> Result<Option<String>> {
                 Ok(match e {
                     Some(x) => {
                         let e = ChangelogEntry::from_str(x)?;
@@ -528,17 +550,17 @@ echo "debcargo testing: suppressing dh-cargo-built-using";;
                     } else {
                         // If unreleased changelog is by someone else, preserve their entries
                         e.items.insert(0, autogenerated_item);
-                        e.items.insert(1, "".to_string());
+                        e.items.insert(1, String::new());
                         let ename = e.maintainer_name();
-                        e.items.insert(2, format!("  [ {} ]", ename));
+                        e.items.insert(2, format!("  [ {ename} ]"));
                     }
-                    (&changelog_data[x.len()..], e.items, ver_bump(&chit.next())?)
+                    (&changelog_data[x.len()..], e.items, ver_bump(chit.next())?)
                 }
                 // Otherwise prepend a new entry to the existing entries
                 _ => (
                     changelog_data.as_str(),
                     vec![autogenerated_item],
-                    ver_bump(&e1)?,
+                    ver_bump(e1)?,
                 ),
             }
         };
@@ -569,9 +591,9 @@ echo "debcargo testing: suppressing dh-cargo-built-using";;
 
         changelog.seek(io::SeekFrom::Start(0))?;
         if changelog_old.is_empty() {
-            write!(changelog, "{}", changelog_new_entry)?;
+            write!(changelog, "{changelog_new_entry}")?;
         } else {
-            write!(changelog, "{}\n{}", changelog_new_entry, changelog_old)?;
+            write!(changelog, "{changelog_new_entry}\n{changelog_old}")?;
         }
         // the new file might be shorter, truncate it to the current cursor position
         let pos = changelog.stream_position()?;
@@ -606,7 +628,6 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
     mut file: F,
 ) -> Result<(Source, bool, bool)> {
     let crate_name = crate_info.crate_name();
-    let deb_upstream_version = deb_info.deb_upstream_version();
     let base_pkgname = deb_info.base_package_name();
     let name_suffix = deb_info.name_suffix();
 
@@ -688,7 +709,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
         build_deps.build_depends.extend(
             ["debhelper-compat (= 13)", "dh-sequence-cargo"]
                 .iter()
-                .map(|x| x.to_string()),
+                .map(ToString::to_string),
         );
 
         // note: please keep this in sync with build_order::dep_features
@@ -696,17 +717,15 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
         //debcargo_info!("default_features: {:?}", default_features);
         //debcargo_info!("default_deps: {:?}", deb_deps(config, &default_deps)?);
         let extra_override_deps = package_field_for_feature(
-            &|x| config.package_depends(x),
+            |x| config.package_depends(x),
             PackageKey::feature("default"),
             &default_features,
         );
-        let build_deps_arch = toolchain_deps(&crate_info.rust_version())
+        let build_deps_arch = toolchain_deps(crate_info.rust_version().as_deref())
             .into_iter()
             .chain(deb_deps(config.allow_prerelease_deps, &default_deps)?)
             .chain(extra_override_deps);
-        if !bins.is_empty() {
-            build_deps.build_depends_arch.extend(build_deps_arch);
-        } else {
+        if bins.is_empty() {
             assert!(lib);
             build_deps
                 .build_depends_arch
@@ -717,29 +736,36 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
                         deb_dep_add_nocheck(&d)
                     }
                 }));
+        } else {
+            build_deps.build_depends_arch.extend(build_deps_arch);
         }
         build_deps
     };
-    let test_deps: Vec<String> = Some(rustc_dep(&crate_info.rust_version(), false))
+    let test_deps: Vec<String> = Some(rustc_dep(crate_info.rust_version().as_deref(), false))
         .into_iter()
         .chain(dev_depends)
         .collect();
 
-    // prefer Cargo.toml homepage, fallback to Cargo.toml repository
-    let homepage = meta
-        .homepage
-        .as_deref()
-        .or(meta.repository.as_deref())
-        .unwrap_or("");
+    let homepage = generate_homepage(
+        &crate_info.manifest().name(),
+        &crate_info.manifest().version().to_string(),
+        meta.homepage.as_deref(),
+        meta.repository.as_deref(),
+        config.crate_src_path.is_none(),
+    );
+
+    // no repack suffix!
+    let plain_upstream_version = control::deb_upstream_version(crate_info.version(), None);
 
     let mut source = Source::new(
         base_pkgname,
         name_suffix,
         crate_name,
-        homepage,
+        &plain_upstream_version,
+        &homepage,
         lib,
         maintainer.to_string(),
-        uploaders.iter().map(|s| s.to_string()).collect(),
+        uploaders.iter().map(ToString::to_string).collect(),
         build_deps,
         requires_root.cloned(),
     )?;
@@ -748,17 +774,17 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
     source.apply_overrides(config);
 
     let mut control = io::BufWriter::new(file("control")?);
-    write!(control, "{}", source)?;
+    write!(control, "{source}")?;
 
     // Summary and description generated from Cargo.toml
     let (crate_summary, crate_description) = crate_info.get_summary_description();
-    let summary_prefix = crate_summary.unwrap_or(format!("Rust crate \"{}\"", crate_name));
+    let summary_prefix = crate_summary.unwrap_or(format!("Rust crate \"{crate_name}\""));
     let description_prefix = {
         let tmp = crate_description.unwrap_or_default();
         if tmp.is_empty() {
             tmp
         } else {
-            format!("{}\n.\n", tmp)
+            format!("{tmp}\n.\n")
         }
     };
 
@@ -796,15 +822,15 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
                 source.name(),
                 crate_name,
                 "@",
-                deb_upstream_version,
-                vec!["--all-features"],
+                &plain_upstream_version,
+                &["--all-features"],
                 &all_features_test_depends,
                 if all_features_test_broken {
-                    vec!["flaky"]
+                    &["flaky"]
                 } else {
-                    vec![]
+                    &[]
                 },
-                all_features_test_arch.deref(),
+                &all_features_test_arch,
             )?
         )?;
 
@@ -819,7 +845,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
             let potential_corner_case = working_features_with_deps
                 .keys()
                 .filter(|x| base_deb_name(x).as_str() != **x)
-                .cloned()
+                .copied()
                 .collect::<Vec<_>>();
             for f in potential_corner_case {
                 let f_ = base_deb_name(f);
@@ -839,7 +865,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
                             dd0.extend(dd);
                         });
                     // go through other feature deps and change f_ to f
-                    for (_, (df, _)) in working_features_with_deps.iter_mut() {
+                    for (df, _) in &mut working_features_with_deps.values_mut() {
                         for feat in df.iter_mut() {
                             if *feat == f_.as_str() {
                                 *feat = f;
@@ -852,17 +878,16 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
                         f,
                     );
                     if dep_feats.contains(f) {
-                        log::debug!("transitive deps of feature {}: {:?}", f, dep_feats);
+                        log::debug!("transitive deps of feature {f}: {dep_feats:?}");
                         debcargo_bail!(
                             "Tried to merge features {} and {} as they are not representable separately\n\
                              in Debian, but this resulted in a feature cycle. You need to manually patch the package.", f, f_);
-                    } else {
-                        debcargo_warn!(
-                            "Merged features {} and {} as they are not representable separately in Debian.\n\
-                             We checked that this does not break the package in an obvious way (feature cycle), however\n\
-                             if there is a more sophisticated breakage, you'll have to manually patch those \
-                             features instead.", f, f_);
                     }
+                    debcargo_warn!(
+                        "Merged features {} and {} as they are not representable separately in Debian.\n\
+                         We checked that this does not break the package in an obvious way (feature cycle), however\n\
+                         if there is a more sophisticated breakage, you'll have to manually patch those \
+                         features instead.", f, f_);
                 }
             }
             working_features_with_deps
@@ -875,7 +900,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
                 .collect::<Vec<_>>()
         );
         let (mut provides, reduced_features_with_deps) = if config.collapse_features {
-            collapse_features(working_features_with_deps)
+            collapse_features(&working_features_with_deps)
         } else {
             reduce_provides(working_features_with_deps)
         };
@@ -888,10 +913,10 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
         );
         // end transforming dependencies
 
-        log::trace!("provides: {:?}", provides);
+        log::trace!("provides: {provides:?}");
         let mut recommends = vec![];
         let mut suggests = vec![];
-        for (&feature, features) in provides.iter() {
+        for (&feature, features) in &provides {
             if feature.is_empty() {
                 continue;
             } else if feature == "default" || features.contains(&"default") {
@@ -906,7 +931,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
         no_features_edge_case.insert("default", (vec![""], vec![]));
         let no_features_edge_case = features_with_deps == no_features_edge_case;
 
-        for (feature, (f_deps, o_deps)) in reduced_features_with_deps.into_iter() {
+        for (feature, (f_deps, o_deps)) in reduced_features_with_deps {
             let pk = PackageKey::feature(feature);
             let f_provides = provides.remove(feature).unwrap();
             let mut crate_features = f_provides.clone();
@@ -916,12 +941,12 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
                 " - Rust source code".to_string()
             } else {
                 match f_provides.len() {
-                    0 => format!(" - feature \"{}\"", feature),
+                    0 => format!(" - feature \"{feature}\""),
                     _ => format!(" - feature \"{}\" and {} more", feature, f_provides.len()),
                 }
             };
             let description_suffix = if feature.is_empty() {
-                format!("Source code for Debianized Rust crate \"{}\"", crate_name)
+                format!("Source code for Debianized Rust crate \"{crate_name}\"")
             } else {
                 format!(
                     "This metapackage enables feature \"{}\" for the \
@@ -930,7 +955,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
                     feature,
                     crate_name,
                     match f_provides.len() {
-                        0 => "".to_string(),
+                        0 => String::new(),
                         1 => format!(
                             "\n\nAdditionally, this package also provides the \
                              \"{}\" feature.",
@@ -962,22 +987,14 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
                 } else {
                     Some(feature)
                 },
-                f_deps,
+                &f_deps,
                 deb_deps(config.allow_prerelease_deps, &o_deps)?,
-                f_provides.clone(),
-                if feature.is_empty() {
-                    recommends.clone()
-                } else {
-                    vec![]
-                },
-                if feature.is_empty() {
-                    suggests.clone()
-                } else {
-                    vec![]
-                },
+                &f_provides.clone(),
+                if feature.is_empty() { &recommends } else { &[] },
+                if feature.is_empty() { &suggests } else { &[] },
             )?;
             // If any overrides present for this package it will be taken care.
-            package.apply_overrides(config, pk, f_provides);
+            package.apply_overrides(config, pk, &f_provides);
 
             if package.summary_check_len().is_err() {
                 writeln!(
@@ -991,7 +1008,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
                 )?;
             }
 
-            write!(control, "\n{}", package)?;
+            write!(control, "\n{package}")?;
 
             // Override pointless overzealous warnings from lintian
             if !feature.is_empty() {
@@ -1034,17 +1051,13 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
                         package.name(),
                         crate_name,
                         f,
-                        deb_upstream_version,
-                        args,
+                        &plain_upstream_version,
+                        &args,
                         &test_depends,
-                        if test_is_broken(f)? {
-                            vec!["flaky"]
-                        } else {
-                            vec![]
-                        },
-                        test_arch.deref(),
+                        if test_is_broken(f)? { &["flaky"] } else { &[] },
+                        &test_arch,
                     )?;
-                    write!(testctl, "\n{}", pkgtest)?;
+                    write!(testctl, "\n{pkgtest}")?;
                 }
             }
         }
@@ -1054,7 +1067,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
 
     if !bins.is_empty() {
         // adding " - binaries" is a bit redundant for users, so just leave as-is
-        let summary_suffix = "".to_string();
+        let summary_suffix = String::new();
         let description_suffix = format!(
             "This package contains the following binaries built from the Rust crate\n\"{}\":\n - {}",
             crate_name,
@@ -1065,10 +1078,10 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
             bin_name,
             name_suffix,
             // if not-a-lib then Source section is already FIXME
-            if !lib {
-                None
-            } else {
+            if lib {
                 Some("FIXME-(packages.\"(name)\".section)")
+            } else {
+                None
             },
             Description {
                 prefix: summary_prefix,
@@ -1081,13 +1094,39 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
         );
 
         // Binary package overrides.
-        bin_pkg.apply_overrides(config, PackageKey::Bin, vec![]);
-        write!(control, "\n{}", bin_pkg)?;
+        bin_pkg.apply_overrides(config, PackageKey::Bin, &[]);
+        write!(control, "\n{bin_pkg}")?;
+    }
+
+    for configured in config.configured_packages() {
+        if let PackageKey::Extra(package) = configured {
+            let mut extra_pkg = Package::new_extra(package.to_string());
+            extra_pkg.apply_overrides(config, configured, &[]);
+            write!(control, "\n{extra_pkg}")?;
+        }
     }
 
     Ok((source, has_dev_deps, test_is_broken("default")?))
 }
 
+fn generate_homepage(
+    name: &str,
+    version: &str,
+    homepage: Option<&str>,
+    repository: Option<&str>,
+    on_crates_io: bool,
+) -> String {
+    let fallback = if on_crates_io {
+        format!("https://crates.io/crates/{name}/{version}",)
+    } else {
+        String::new()
+    };
+
+    // prefer Cargo.toml homepage, fallback to Cargo.toml repository, or crates.io page as a last
+    // resort
+    homepage.or(repository).unwrap_or(&fallback).to_owned()
+}
+
 fn generate_test_dependencies(
     f: &str,
     feature_deps: &[&str],
@@ -1103,13 +1142,13 @@ fn generate_test_dependencies(
                 .into_iter()
                 .flatten()
         })
-        .map(|s| s.to_string())
+        .map(ToString::to_string)
         .chain(test_deps.to_owned())
         .collect::<Vec<_>>()
 }
 
 fn collapse_features(
-    orig_features_with_deps: CrateDepInfo,
+    orig_features_with_deps: &CrateDepInfo,
 ) -> (BTreeMap<&'static str, Vec<&'static str>>, CrateDepInfo) {
     let (provides, deps) = orig_features_with_deps.iter().fold(
         (Vec::new(), Vec::new()),
@@ -1146,13 +1185,13 @@ fn reduce_provides(
     // If any features have duplicate dependencies, deduplicate them by
     // making all the subsequent ones depend on the first one.
     let mut features_rev_deps = HashMap::new();
-    for (&f, dep) in features_with_deps.iter() {
+    for (&f, dep) in &features_with_deps {
         if !features_rev_deps.contains_key(dep) {
             features_rev_deps.insert(dep.clone(), vec![]);
         }
         features_rev_deps.get_mut(dep).unwrap().push(f);
     }
-    for (_, ff) in features_rev_deps.into_iter() {
+    for (_, ff) in features_rev_deps {
         let f0 = ff[0];
         for f in &ff[1..] {
             features_with_deps.insert(f, (vec![f0], vec![]));
@@ -1162,7 +1201,7 @@ fn reduce_provides(
     // Calculate provides by following 0- or 1-length dependency lists.
     let mut provides = BTreeMap::new();
     let mut provided = Vec::new();
-    for (&f, (ref ff, ref dd)) in features_with_deps.iter() {
+    for (&f, (ref ff, ref dd)) in &features_with_deps {
         //debcargo_info!("provides considering: {:?}", &f);
         if !dd.is_empty() {
             continue;
@@ -1203,13 +1242,13 @@ fn reduce_provides(
     (provides, features_with_deps)
 }
 
-pub(crate) fn toolchain_deps(min_rust_version: &Option<String>) -> Vec<String> {
+pub(crate) fn toolchain_deps(min_rust_version: Option<&str>) -> Vec<String> {
     let rustc = rustc_dep(min_rust_version, true);
     // libstd-rust-dev here is needed to pick up the right arch variant for cross-builds!
     ["cargo:native".into(), rustc, "libstd-rust-dev".into()].into()
 }
 
-fn rustc_dep(min_ver: &Option<String>, native: bool) -> String {
+fn rustc_dep(min_ver: Option<&str>, native: bool) -> String {
     let native = if native { ":native" } else { "" };
     if let Some(min_ver) = min_ver {
         format!("rustc{native} (>= {min_ver})")
@@ -1252,31 +1291,132 @@ fn changelog_first_last(tempdir: &Path) -> Result<(i32, i32)> {
 
 #[cfg(test)]
 mod test {
-    use super::rustc_dep;
+    use super::{generate_homepage, rustc_dep};
 
     #[test]
     fn rustc_dep_includes_minver() {
-        assert_eq!(
-            "rustc:native (>= 1.65)",
-            rustc_dep(&Some("1.65".to_string()), true)
-        );
+        assert_eq!("rustc:native (>= 1.65)", rustc_dep(Some("1.65"), true));
     }
 
     #[test]
     fn rustc_dep_excludes_minver() {
-        assert_eq!("rustc:native", rustc_dep(&None, true));
+        assert_eq!("rustc:native", rustc_dep(None, true));
     }
 
     #[test]
     fn rustc_dep_includes_minver_autopkgtest() {
-        assert_eq!(
-            "rustc (>= 1.65)",
-            rustc_dep(&Some("1.65".to_string()), false)
-        );
+        assert_eq!("rustc (>= 1.65)", rustc_dep(Some("1.65"), false));
     }
 
     #[test]
     fn rustc_dep_excludes_minver_autopkgtest() {
-        assert_eq!("rustc", rustc_dep(&None, false));
+        assert_eq!("rustc", rustc_dep(None, false));
+    }
+
+    #[test]
+    fn homepage_is_homepage() {
+        assert_eq!(
+            "https://example.com",
+            generate_homepage(
+                "crate",
+                "1.0".into(),
+                Some("https://example.com"),
+                Some("https://example.com/repo"),
+                true
+            )
+        );
+
+        assert_eq!(
+            "https://example.com",
+            generate_homepage(
+                "crate",
+                "1.0".into(),
+                Some("https://example.com"),
+                None,
+                true
+            )
+        );
+
+        assert_eq!(
+            "https://example.com",
+            generate_homepage(
+                "crate",
+                "1.0".into(),
+                Some("https://example.com"),
+                Some("https://example.com/repo"),
+                false
+            )
+        );
+
+        assert_eq!(
+            "https://example.com",
+            generate_homepage(
+                "crate",
+                "1.0".into(),
+                Some("https://example.com"),
+                None,
+                false
+            )
+        );
+    }
+
+    #[test]
+    fn homepage_is_repository() {
+        assert_eq!(
+            "https://example.com/repo",
+            generate_homepage(
+                "crate",
+                "1.0".into(),
+                None,
+                Some("https://example.com/repo"),
+                true
+            )
+        );
+
+        assert_eq!(
+            "https://example.com/repo",
+            generate_homepage(
+                "crate",
+                "1.0".into(),
+                None,
+                Some("https://example.com/repo"),
+                true
+            )
+        );
+
+        assert_eq!(
+            "https://example.com/repo",
+            generate_homepage(
+                "crate",
+                "1.0".into(),
+                None,
+                Some("https://example.com/repo"),
+                false
+            )
+        );
+
+        assert_eq!(
+            "https://example.com/repo",
+            generate_homepage(
+                "crate",
+                "1.0".into(),
+                None,
+                Some("https://example.com/repo"),
+                false
+            )
+        );
+    }
+
+    #[test]
+    fn homepage_is_fallback() {
+        assert_eq!(
+            "https://crates.io/crates/crate/1.0",
+            generate_homepage("crate", "1.0".into(), None, None, true)
+        );
+
+        assert_eq!(
+            "",
+            generate_homepage("crate", "1.0".into(), None, None, false)
+        );
     }
 }
